==> haskell-colour-2.3.6-404.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 colour
version:              2.3.6
visibility:           public
id:                   colour-2.3.6-H6QKK8UT9PiEnQ6wB0s1YD
key:                  colour-2.3.6-H6QKK8UT9PiEnQ6wB0s1YD
license:              MIT
maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
homepage:             http://www.haskell.org/haskellwiki/Colour
synopsis:             A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.

category:             data, graphics
abi:                  d8f103edfbf257dee0c5ceecb929e958
exposed:              True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear

hidden-modules:
    Data.Colour.Internal Data.Colour.Chan Data.Colour.RGB
    Data.Colour.Matrix Data.Colour.CIE.Chromaticity

import-dirs:          /usr/lib/ghc-9.6.6/site-local/colour-2.3.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/colour-2.3.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/colour-2.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colour
hs-libraries:         HScolour-2.3.6-H6QKK8UT9PiEnQ6wB0s1YD
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html:         /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colour-2.3.6-406-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-colour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 colour
version:              2.3.6
visibility:           public
id:                   colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z
key:                  colour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z
license:              MIT
maintainer:           Russell O'\''Connor <roconnor@theorem.ca>
author:               Russell O'\''Connor
homepage:             http://www.haskell.org/haskellwiki/Colour
synopsis:             A model for human colour/color perception
description:
    This package provides a data type for colours and transparency.
    Colours can be blended and composed.
    Various colour spaces are supported.
    A module of colour names ("Data.Colour.Names") is provided.

category:             data, graphics
abi:                  2c215be84beeeae00bf8f0d485b56f8c
exposed:              True
exposed-modules:
    Data.Colour Data.Colour.CIE Data.Colour.CIE.Illuminant
    Data.Colour.Names Data.Colour.RGBSpace Data.Colour.RGBSpace.HSL
    Data.Colour.RGBSpace.HSV Data.Colour.SRGB Data.Colour.SRGB.Linear

hidden-modules:
    Data.Colour.Internal Data.Colour.Chan Data.Colour.RGB
    Data.Colour.Matrix Data.Colour.CIE.Chromaticity

import-dirs:          /usr/lib/ghc-9.6.6/site-local/colour-2.3.6
library-dirs:         /usr/lib/ghc-9.6.6/site-local/colour-2.3.6
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/colour-2.3.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-colour
hs-libraries:         HScolour-2.3.6-DLRFrLUBudd2Y8gC5KfK2z
depends:              base-4.18.2.1
haddock-interfaces:   /usr/share/doc/haskell-colour/html/colour.haddock
haddock-html:         /usr/share/doc/haskell-colour/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
